@@ -13,7 +13,7 @@ use warnings;
 use Exporter 'import';
 
 our $VERSION = '1.01';
-our @EXPORT = qw(Extend Extends Alias AddMethod Decorate ApplyRole InitHook Unload);
+our @EXPORT = qw(Extend Extends GlobExtends Alias AddMethod Decorate ApplyRole InitHook Unload);
 
 ################################################################################
 =pod
@@ -174,13 +174,21 @@ sub Extends {
     for my $name (keys %extend) {
         # Create the method
         no strict 'refs';
+        my $package = ref($object) || $object;  # Get the package or class name
+
         if (ref $extend{$name} eq 'CODE') {
             # If $extend{$name} is a coderef, directly assign it
-            *{ref($object) . "::$name"} = sub { unshift @_, $object; goto &{$extend{$name}} };
+            *{$package . "::$name"} = sub {
+                my $self = shift;
+                return $extend{$name}->($self, @_);
+            };
         }
         elsif (ref $extend{$name} eq 'SCALAR' && defined ${$extend{$name}} && ref ${$extend{$name}} eq 'CODE') {
             # If $method_ref is a reference to a scalar containing a coderef
-            *{ref($object) . "::$name"} = sub { unshift @_, $object; goto &${$extend{$name}} };
+            *{$package . "::$name"} = sub {
+                my $self = shift;
+                return ${$extend{$name}}->($self, @_);
+            };
         }
         else {
             die "Invalid method reference provided for $name. Expected CODE or reference to CODEREF but got ".(ref($extend{$name})).".";
@@ -192,6 +200,20 @@ sub Extends {
 
 ################################################################################
 
+sub GlobExtends {
+    my ($glob, %methods) = @_;
+    my $package = ref $glob || 'main';
+
+    no strict 'refs';
+    for my $name (keys %methods) {
+        *{"${package}::$name"} = $methods{$name};
+    }
+
+    return $glob;
+}
+
+################################################################################
+
 =head2 Alias($object, $existing_method, $new_name)
 
 Creates an alias for an existing method in the object with a new name.
